summaryrefslogtreecommitdiffstats
path: root/kmymoney2/views/kinstitutionsview.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/views/kinstitutionsview.h')
-rw-r--r--kmymoney2/views/kinstitutionsview.h23
1 files changed, 12 insertions, 11 deletions
diff --git a/kmymoney2/views/kinstitutionsview.h b/kmymoney2/views/kinstitutionsview.h
index 3a35713..9c1ab96 100644
--- a/kmymoney2/views/kinstitutionsview.h
+++ b/kmymoney2/views/kinstitutionsview.h
@@ -42,10 +42,11 @@
class KInstitutionsView : public KInstitutionsViewDecl
{
Q_OBJECT
+ TQ_OBJECT
private:
public:
- KInstitutionsView(QWidget *parent=0, const char *name=0);
+ KInstitutionsView(TQWidget *tqparent=0, const char *name=0);
virtual ~KInstitutionsView();
public slots:
@@ -58,22 +59,22 @@ public slots:
void show(void);
/**
- * Override the base class behaviour to restore the layout. Do not
- * do this in show() because show() itself may change the layout
+ * Override the base class behaviour to restore the tqlayout. Do not
+ * do this in show() because show() itself may change the tqlayout
* in undesired ways.
*/
void polish(void);
- void slotReconcileAccount(const MyMoneyAccount& acc, const QDate& reconciliationDate, const MyMoneyMoney& endingBalance);
+ void slotReconcileAccount(const MyMoneyAccount& acc, const TQDate& reconciliationDate, const MyMoneyMoney& endingBalance);
protected:
void loadAccounts(void);
// load accounts that are kept at a specific institution
- void loadSubAccounts(KMyMoneyAccountTreeItem* parent, const QString& institutionId);
+ void loadSubAccounts(KMyMoneyAccountTreeItem* tqparent, const TQString& institutionId);
- // load stock accounts under the investment account (parent)
- void loadSubAccounts(KMyMoneyAccountTreeItem* parent);
+ // load stock accounts under the investment account (tqparent)
+ void loadSubAccounts(KMyMoneyAccountTreeItem* tqparent);
protected slots:
void slotUpdateNetWorth(void);
@@ -85,7 +86,7 @@ private:
*
* @param type account type as defined in MyMoneyAccount::accountTypeE
*/
- const QPixmap accountImage(const MyMoneyAccount::accountTypeE type) const;
+ const TQPixmap accountImage(const MyMoneyAccount::accountTypeE type) const;
signals:
/**
@@ -117,9 +118,9 @@ signals:
private:
MyMoneyAccount m_reconciliationAccount;
- QMap<QString, MyMoneyAccount> m_accountMap;
- QMap<QString, MyMoneySecurity> m_securityMap;
- QMap<QString, unsigned long> m_transactionCountMap;
+ TQMap<TQString, MyMoneyAccount> m_accountMap;
+ TQMap<TQString, MyMoneySecurity> m_securityMap;
+ TQMap<TQString, unsigned long> m_transactionCountMap;
/// set if a view needs to be reloaded during show()
bool m_needReload;